PET_sogamoso: PET_sogamoso

PET_sogamosoR Documentation

PET_sogamoso

Description

Distributed monthly potential evapotranspiration in Sogamoso River Basin from January 2012 to December 2016

Usage

PET_sogamoso

Format

data.frame

PET_sogamoso

Data frame, it contains evapotranspiration data, representing the cells in each row, and the evapotranspiration info. by month in each column. The cell rank should match the cell ID in the cells data frame.

References

Duque-Gardeazabal, N. (2018). "Estimation of rainfall fields in data scarce colombian watersheds, by blending remote sensed and rain gauge data, using kernel functions". Master thesis. Universidad Nacional de Colombia, Bogotá, Colombia.


DWBmodelUN documentation built on July 28, 2026, 5:09 p.m.