| simDWB.sogamoso | R Documentation |
Simulated runoff by the DWBmodelUN in the same stations where there were observed data from the Sogamoso basin
simDWB.sogamoso
data.frame
Data frame, it contains simulated runoff time series at the same 32 stations within the basin.
Duque-Gardeazabal, N. (2018). "Estimation of rainfall fields in data scarce colombian watersheds, by blending remote sensed and rain gauge data, using kernel functions". Master thesis. Universidad Nacional de Colombia, Bogotá, Colombia.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.