| cellBasins | R Documentation |
This function identifies the cells that are within a basin. The runoff produced by those cells will be used, either to calculate the water availability or to compare the simulated variable with the observed runoff in certain streamflow gauges.
cellBasins(gruLoc, basins)
gruLoc |
raster ( |
basins |
polygons ( |
a list that comprise two dataframes. The first one, the list of cells in each of the basins contained in the shapefile (cellBasins),
and second a table that associates the coordinates of each cell with the assigned number (cellTable).
Pedro Felipe Arboleda Obando <pfarboledao@unal.edu.co>
Nicolas Duque Gardeazabal <nduqueg@unal.edu.co>
Carolina Vega Viviescas <cvegav@unal.edu.co>
David Zamora <dazamoraa@unal.edu.co>
Water Resources Engineering Research Group - GIREH Universidad Nacional de Colombia - sede Bogota
data("GRU","basins")
cellBasins <- cellBasins(GRU, basins)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.